pub enum InitError {
RuntimeUnavailable,
InstanceCreationFailed,
DeviceEnumerationFailed,
DeviceUnavailable,
DeviceCreationFailed,
}Expand description
Failure to initialize a Vulkan backend instance.
Variants
No Vulkan loader could be loaded, or it predates Vulkan 1.3 (or this is a placeholder build).
InstanceCreationFailed
vkCreateInstance failed.
DeviceEnumerationFailed
Physical-device enumeration failed inside the loader or an ICD.
No requested or suitable Vulkan 1.3 compute device is available on this host.
DeviceCreationFailed
vkCreateDevice or the device-level setup failed.